@@ -1,4 +1,4 @@
-/* $scrotwm: swm_hack.c,v 1.2 2009/02/07 19:49:58 mcbride Exp $ */
+/* $scrotwm: swm_hack.c,v 1.3 2011/06/03 22:51:54 mcbride Exp $ */
 /*
  * Copyright (c) 2009 Marco Peereboom <marco@peereboom.us>
  * Copyright (c) 2009 Ryan McBride <mcbride@countersiege.com>
@@ -77,6 +77,14 @@ MyRoot(Display * dpy)
 	return root;
 }
 
+
+typedef Atom	(XIA) (Display *display, char *atom_name, Bool
+		    only_if_exists);
+
+typedef int	(XCP) (Display *display, Window w, Atom property,
+		    Atom type, int format, int mode, unsigned char *data,
+		    int nelements);
+
 #define SWM_PROPLEN	(16)
 void
 set_property(Display *dpy, Window id, char *name, char *val)
@@ -84,11 +92,22 @@ set_property(Display *dpy, Window id, char *name, char *val)
 	Atom			atom = 0;
 	char			prop[SWM_PROPLEN];
 
+	static XIA         	*xia = NULL;
+	static XCP         	*xcp = NULL;
+
+	/* find the real Xlib and the real X function */
+	if (!lib_xlib)
+		lib_xlib = dlopen("libX11.so", RTLD_GLOBAL | RTLD_LAZY);
+	if (!xia)
+		xia = (XIA *) dlsym(lib_xlib, "XInternAtom");
+	if (!xcp)
+		xcp = (XCP *) dlsym(lib_xlib, "XChangeProperty");
+
 	/* Try to update the window's workspace property */
-	atom = XInternAtom(dpy, name, False);
+	atom = (*xia)(dpy, name, False);
 	if (atom) 
 		if (snprintf(prop, SWM_PROPLEN, "%s", val) < SWM_PROPLEN)
-			XChangeProperty(dpy, id, atom, XA_STRING,
+			(*xcp)(dpy, id, atom, XA_STRING,
 			    8, PropModeReplace, prop, SWM_PROPLEN);
 }
 
